@@ -1413,6 +1413,7 @@ class SpokeLocalPortfolioTask(ProvisioningTask, manifest_tasks.ManifestMixen):
                 tasks.append(
                     portfoliomanagement_tasks.DeletePortfolio(
                         manifest_file_path=self.manifest_file_path,
+                        spoke_local_portfolio_name=self.spoke_local_portfolio_name,
                         account_id=task_def.get("account_id"),
                         region=task_def.get("region"),
                         portfolio=task_def.get("portfolio"),
@@ -1451,8 +1452,9 @@ class SpokeLocalPortfolioTask(ProvisioningTask, manifest_tasks.ManifestMixen):
             )
 
             if len(task_def.get("associations", [])) > 0:
-                create_associations_for_portfolio_task = portfoliomanagement_tasks.CreateAssociationsForPortfolioTask(
+                create_associations_for_portfolio_task = portfoliomanagement_tasks.CreateAssociationsForSpokeLocalPortfolioTask(
                     **create_spoke_local_portfolio_task_as_dependency_params,
+                    spoke_local_portfolio_name=self.spoke_local_portfolio_name,
                     sharing_mode=sharing_mode,
                     cache_invalidator=self.cache_invalidator,
                     associations=task_def.get("associations"),
@@ -1466,6 +1468,7 @@ class SpokeLocalPortfolioTask(ProvisioningTask, manifest_tasks.ManifestMixen):
             if product_generation_method == "import":
                 import_into_spoke_local_portfolio_task = portfoliomanagement_tasks.ImportIntoSpokeLocalPortfolioTask(
                     **create_spoke_local_portfolio_task_as_dependency_params,
+                    spoke_local_portfolio_name=self.spoke_local_portfolio_name,
                     sharing_mode=sharing_mode,
                     cache_invalidator=self.cache_invalidator,
                     puppet_account_id=task_def.get("puppet_account_id"),
@@ -1474,6 +1477,7 @@ class SpokeLocalPortfolioTask(ProvisioningTask, manifest_tasks.ManifestMixen):
             else:
                 copy_into_spoke_local_portfolio_task = portfoliomanagement_tasks.CopyIntoSpokeLocalPortfolioTask(
                     **create_spoke_local_portfolio_task_as_dependency_params,
+                    spoke_local_portfolio_name=self.spoke_local_portfolio_name,
                     sharing_mode=sharing_mode,
                     cache_invalidator=self.cache_invalidator,
                     puppet_account_id=task_def.get("puppet_account_id"),
@@ -1486,9 +1490,10 @@ class SpokeLocalPortfolioTask(ProvisioningTask, manifest_tasks.ManifestMixen):
                     "puppet_account_id": task_def.get("puppet_account_id"),
                     "should_use_sns": task_def.get("should_use_sns"),
                 }
-                create_launch_role_constraints_for_portfolio = portfoliomanagement_tasks.CreateLaunchRoleConstraintsForPortfolio(
+                create_launch_role_constraints_for_portfolio = portfoliomanagement_tasks.CreateLaunchRoleConstraintsForSpokeLocalPortfolioTask(
                     **create_spoke_local_portfolio_task_as_dependency_params,
                     **create_launch_role_constraints_for_portfolio_task_params,
+                    spoke_local_portfolio_name=self.spoke_local_portfolio_name,
                     sharing_mode=sharing_mode,
                     cache_invalidator=self.cache_invalidator,
                     product_generation_method=product_generation_method,
