@@ -34,6 +34,7 @@ def run_tasks(
     execution_mode="hub",
     cache_invalidator="now",
     on_complete_url=None,
+    running_exploded=False,
 ):
     codebuild_id = os.getenv("CODEBUILD_BUILD_ID", "LOCAL_BUILD")
     if is_list_launches:
@@ -72,7 +73,8 @@ def run_tasks(
 
     logger.info(f"About to run workflow with {num_workers} workers")
 
-    tasks.print_stats()
+    if not running_exploded:
+        tasks.print_stats()
 
     should_use_shared_scheduler = config.get_should_use_shared_scheduler(
         puppet_account_id
@@ -339,7 +341,10 @@ def run_tasks(
         logger.info(f.status)
         logger.info(f.reason)
 
-    sys.exit(exit_status_code)
+    if running_exploded:
+        pass
+    else:
+        sys.exit(exit_status_code)
 
 
 def run_tasks_for_bootstrap_spokes_in_ou(tasks_to_run, num_workers):
